==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-timePicker.dart <==
/*
Description:

Displays a dialog containing a material design time picker.The returned Future resolves to the time selected by the user when the user closes the dialog. If the user cancels the dialog,null is returned.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-timePicker.dart';

Usage:
The parameters such as headerColor,bodybgColor,selectColor and the color & font size of the time ,buttonText can be passed using the 'TimePickerParameters' class.

void Function(TimeOfDay) onSelect is used to return the time selected.
The time picker is passed as a Voidcallback to the pressed control of any widget.

- Defining the callback and Time Picker objects

 TimePickerParameters timePickerObj = new TimePickerParameters(
      bodybgColor: Colors.grey,
      selectColor: Colors.black,
      headerColor: Colors.black,
      timeColor: Colors.black,
      buttonText:Colors.black,

    );

    onclicktimePicker(TimeOfDay t) {
      print(t);
    }
    FlatButtonParameters timePickerButton = new FlatButtonParameters(child: Text('Select Time',style: TextStyle(color: Colors.white),),color: Colors.pink,height: 30);
    onPressTimePickerButton(bool b){
      CustomTimePicker(timePickerObj, context, onclicktimePicker);

    }


-Sample Implementation

CustomFlatButton(timePickerButton, onPressTimePickerButton, null)


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as consts;

CustomTimePicker(TimePickerParameters param, context,
    void Function(TimeOfDay) onSelect) async {
  if (param == null) {
    TimeOfDay time = await showTimePicker(
      initialTime: TimeOfDay.now(),
      context: context,
      builder: (BuildContext context, Widget child) {
        return Theme(
            data: Theme.of(context).copyWith(
          primaryColor: Theme.of(context).primaryColor,
          accentColor: Theme.of(context).accentColor,
          colorScheme: ColorScheme.light(
            primary: Theme.of(context).buttonColor,
          ),
          dialogBackgroundColor: Theme.of(context).backgroundColor,
          textTheme: TextTheme(
            subhead: TextStyle(color: Theme.of(context).accentIconTheme.color),
            body1: TextStyle(color: Theme.of(context).accentIconTheme.color),
            caption: TextStyle(color: Theme.of(context).accentIconTheme.color),
          ),
          buttonTheme: ButtonThemeData(textTheme: ButtonTextTheme.primary),
        ));

        //dialogBackgroundColor: Colors.white,//Background color
      },
    );

    if (time != null) {
      print(time);
    }
  } else {
    TimeOfDay time = await showTimePicker(
      initialTime: TimeOfDay.now(),
      context: context,
      builder: (BuildContext context, Widget child) {
        return Theme(
          data: Theme.of(context).copyWith(
            //OK/Cancel button text color
            primaryColor: (param.headerColor != null)
                ? param.headerColor
                : Theme.of(context).primaryColor,

            accentColor: (param.selectColor != null)
                ? param.selectColor
                : Theme.of(context).accentColor,
            colorScheme: ColorScheme.light(
              primary: (param.buttonText != null)
                  ? param.buttonText
                  : Theme.of(context).buttonColor,
            ),
            dialogBackgroundColor: (param.bodybgColor != null)
                ? param.bodybgColor
                : Theme.of(context).backgroundColor,
            textTheme: TextTheme(
              subhead: TextStyle(
                  color: (param.timeColor != null)
                      ? param.timeColor
                      : Theme.of(context).accentIconTheme.color,
                  fontWeight: (param.fontWeight != null)
                      ? param.fontWeight
                      : consts.fontBold,
                  fontSize: param.timeSize != null
                      ? param.timeSize
                      : consts.font_medium,
                  fontFamily: param.fontFamily != null
                      ? param.fontFamily
                      : Theme.of(context).textTheme.caption.fontFamily),
            ),
            buttonTheme: ButtonThemeData(textTheme: ButtonTextTheme.primary),
          ),
          child: child,
        );
      },
    );
    if (time != null) {
      onSelect(time);
    }
  }
}

==> flutter_catalogue_widgets-0.0.7.tar.gz: lib/custom-timePicker.dart <==
/*
Description:

Displays a dialog containing a material design time picker.The returned Future resolves to the time selected by the user when the user closes the dialog. If the user cancels the dialog,null is returned.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-timePicker.dart';

Usage:
The parameters such as headerColor,bodybgColor,selectColor and the color & font size of the time ,buttonText can be passed using the 'TimePickerParameters' class.

void Function(TimeOfDay) onSelect is used to return the time selected.
The time picker is passed as a Voidcallback to the pressed control of any widget.

- Defining the callback and Time Picker objects

 TimePickerParameters timePickerObj = new TimePickerParameters(
      bodybgColor: Colors.grey,
      selectColor: Colors.black,
      headerColor: Colors.black,
      timeColor: Colors.black,
      buttonText:Colors.black,

    );

    onclicktimePicker(TimeOfDay t) {
      print(t);
    }
    FlatButtonParameters timePickerButton = new FlatButtonParameters(child: Text('Select Time',style: TextStyle(color: Colors.white),),color: Colors.pink,height: 30);
    onPressTimePickerButton(bool b){
      customTimePicker(timePickerObj, context, onclicktimePicker);

    }


-Sample Implementation

customFlatButton(timePickerButton, onPressTimePickerButton, null)


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as consts;

customTimePicker(TimePickerParameters param, context,
    void Function(TimeOfDay) onSelect) async {
  if (param == null) {
    TimeOfDay time = await showTimePicker(
      initialTime: TimeOfDay.now(),
      context: context,
      builder: (BuildContext context, Widget child) {
        return Theme(
            data: Theme.of(context).copyWith(
          primaryColor: Theme.of(context).primaryColor,
          accentColor: Theme.of(context).accentColor,
          colorScheme: ColorScheme.light(
            primary: Theme.of(context).buttonColor,
          ),
          dialogBackgroundColor: Theme.of(context).backgroundColor,
          textTheme: TextTheme(
            subhead: TextStyle(color: Theme.of(context).accentIconTheme.color),
            body1: TextStyle(color: Theme.of(context).accentIconTheme.color),
            caption: TextStyle(color: Theme.of(context).accentIconTheme.color),
          ),
          buttonTheme: ButtonThemeData(textTheme: ButtonTextTheme.primary),
        ));

        //dialogBackgroundColor: Colors.white,//Background color
      },
    );

    if (time != null) {
      print(time);
    }
  } else {
    TimeOfDay time = await showTimePicker(
      initialTime: TimeOfDay.now(),
      context: context,
      builder: (BuildContext context, Widget child) {
        return Theme(
          data: Theme.of(context).copyWith(
            //OK/Cancel button text color
            primaryColor: (param.headerColor != null)
                ? param.headerColor
                : Theme.of(context).primaryColor,

            accentColor: (param.selectColor != null)
                ? param.selectColor
                : Theme.of(context).accentColor,
            colorScheme: ColorScheme.light(
              primary: (param.buttonText != null)
                  ? param.buttonText
                  : Theme.of(context).buttonColor,
            ),
            dialogBackgroundColor: (param.bodybgColor != null)
                ? param.bodybgColor
                : Theme.of(context).backgroundColor,
            textTheme: TextTheme(
              subhead: TextStyle(
                  color: (param.timeColor != null)
                      ? param.timeColor
                      : Theme.of(context).accentIconTheme.color,
                  fontWeight: (param.fontWeight != null)
                      ? param.fontWeight
                      : consts.fontBold,
                  fontSize: param.timeSize != null
                      ? param.timeSize
                      : consts.font_medium,
                  fontFamily: param.fontFamily != null
                      ? param.fontFamily
                      : Theme.of(context).textTheme.caption.fontFamily),
            ),
            buttonTheme: ButtonThemeData(textTheme: ButtonTextTheme.primary),
          ),
          child: child,
        );
      },
    );
    if (time != null) {
      onSelect(time);
    }
  }
}
